CCSDSPy - IO Interface for Reading CCSDS Data in Python.
========================================================

.. image:: https://api.travis-ci.org/ddasilva/ccsdspy.svg?branch=master
    :target: https://travis-ci.org/ddasilva/ccsdspy
    :alt: Travis Status
          
This package provides a Python interface for reading tightly packed bits in the CCSDS format used for many NASA and ESA missions.
 